@@ -7,7 +7,10 @@ import codecs
 import configparser
 from time import localtime, strftime
 from subprocess import Popen, PIPE, STDOUT, call
+import gi
+gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk
+
 TUNED_CONF = """[sysctl]\n"""
 
 
@@ -47,7 +50,7 @@ class Config:
             self.temp = configparser.RawConfigParser()
             self.temp.read(self.configFile)
             self.temp.set('global', 'lastFile', filename)
-            with open(self.configFile, 'wb') as cfgfile:
+            with open(self.configFile, 'w') as cfgfile:
                 self.temp.write(cfgfile)
             self.config['lastfile'] = filename
 
@@ -317,7 +320,7 @@ class Config:
 
     def saveSnapshot(self, data):
         tempconfig = configparser.RawConfigParser()
-        tempconfig.readfp(io.BytesIO(self.cache))
+        tempconfig.readfp(io.StringIO(self.cache))
         snapcat = tempconfig.items('categories')
         out = {}
         for opt, val in snapcat:
