@@ -13,9 +13,9 @@ class commonview:
 
     def cleanUp(self):
         for value in self.contentTable.get_children():
-            if value.get_name() == "controls":
+            if Gtk.Buildable.get_name(value) == "controls":
                 self.ctrl = value
-            if value.get_name() == "profileSelectorBox":
+            if Gtk.Buildable.get_name(value) == "profileSelectorBox":
                 self.selector = value
             self.contentTable.remove(value)
 
@@ -79,12 +79,13 @@ class commonview:
                         # scale control
                         frameContent[catCntr]['texts'][contentCntr] = Gtk.HScale()
                         frameContent[catCntr]['texts'][contentCntr].set_range(self.config.ctlGuiParams[catCntr][val][0], self.config.ctlGuiParams[catCntr][val][1])
-                        frameContent[catCntr]['texts'][contentCntr].set_update_policy(Gtk.UPDATE_CONTINUOUS)
+                        #frameContent[catCntr]['texts'][contentCntr].set_update_policy(Gtk.UPDATE_CONTINUOUS)
                         frameContent[catCntr]['texts'][contentCntr].set_value(int(self.config.ctlParams[catCntr][val]))
                         frameContent[catCntr]['texts'][contentCntr].set_digits(0)
                     else:
                         # input field
-                        frameContent[catCntr]['texts'][contentCntr] = Gtk.Entry(256)
+                        frameContent[catCntr]['texts'][contentCntr] = Gtk.Entry()
+                        frameContent[catCntr]['texts'][contentCntr].set_max_length(256)
                         frameContent[catCntr]['texts'][contentCntr].set_alignment(0)
                         frameContent[catCntr]['texts'][contentCntr].set_text(self.config.ctlParams[catCntr][val])
                     frameContent[catCntr]['texts'][contentCntr].connect("button-release-event", self.checkStar, catCntr, contentCntr, val, frameContent[catCntr]['labels'][contentCntr])
@@ -105,7 +106,7 @@ class commonview:
         self.ret = {}
         self.property_cntr = 0
         for value in self.contentTable.get_children():
-            if value.get_name() == "controls" or value.get_name() == "profileSelectorBox":
+            if Gtk.Buildable.get_name(value) == "controls" or Gtk.Buildable.get_name(value) == "profileSelectorBox":
                 continue
             self.ret[value.get_label()] = {}
             for content in value:
@@ -128,7 +129,7 @@ class commonview:
         self.ret = {}
         self.property_cntr = 0
         for value in self.contentTable.get_children():
-            if value.get_name() == "controls" or value.get_name() == "profileSelectorBox":
+            if Gtk.Buildable.get_name(value) == "controls" or Gtk.Buildable.get_name(value) == "profileSelectorBox":
                 continue
             self.ret[value.get_label()] = {}
             for content in value:
