@@ -7,7 +7,7 @@ from gi.repository import Gtk
 from gi.repository import GObject
 import os
 from functools import reduce
-import ethtool
+import tuna.new_eth as ethtool
 import tuna.tuna_sched as tuna_sched
 
 import gi
@@ -20,7 +20,8 @@ class irq_druid:
         self.irqs = irqs
         self.ps = ps
         self.irq = irq
-        self.window = Gtk.Builder(gladefile)
+        self.window = Gtk.Builder()
+        self.window.add_objects_from_file(gladefile, ("set_irq_attributes", "tuna"))
         #self.window = Gtk.glade.XML(gladefile, "set_irq_attributes", "tuna")
         self.dialog = self.window.get_object("set_irq_attributes")
         pixbuf = self.dialog.render_icon(Gtk.STOCK_PREFERENCES,
@@ -33,6 +34,7 @@ class irq_druid:
         self.window.connect_signals(event_handlers)
 
         self.sched_pri = self.window.get_object("irq_pri_spinbutton")
+        self.sched_pri.set_range(0, 99)
         self.sched_policy = self.window.get_object("irq_policy_combobox")
         self.affinity = self.window.get_object("irq_affinity_text")
         text = self.window.get_object("irq_text")
@@ -307,11 +309,11 @@ class irqview:
 
         menu = Gtk.Menu()
 
-        setattr = Gtk.MenuItem(_("_Set IRQ attributes"))
+        setattr = Gtk.MenuItem(_("_Set IRQ attributes"), use_underline = True)
         if self.refreshing:
-            refresh = Gtk.MenuItem(_("Sto_p refreshing the IRQ list"))
+            refresh = Gtk.MenuItem(_("Sto_p refreshing the IRQ list"), use_underline = True)
         else:
-            refresh = Gtk.MenuItem(_("_Refresh the IRQ list"))
+            refresh = Gtk.MenuItem(_("_Refresh the IRQ list"), use_underline = True)
 
         menu.add(setattr)
         menu.add(refresh)
@@ -322,7 +324,7 @@ class irqview:
         setattr.show()
         refresh.show()
 
-        menu.popup(None, None, None, event.button, event.time)
+        menu.popup(None, None, None, event, event.button, event.time)
 
     def toggle_mask_cpu(self, cpu, enabled):
         if not enabled:
