@@ -9,11 +9,11 @@ import sys
 import shlex
 import fnmatch
 import platform
-import ethtool
+import tuna.new_eth as ethtool
 import procfs
 from procfs import utilist
-from . import help
-import tuna.tuna_sched as tuna_sched
+from tuna import help
+from tuna import tuna_sched
 
 try:
     fntable
@@ -58,7 +58,7 @@ def iskthread(pid):
     # in this function, so that they know that the thread vanished and
     # can act accordingly, removing entries from tree views, etc
     try:
-        f = open("/proc/%d/smaps" % pid)
+        f = open(f"/proc/{pid}/smaps")
     except IOError:
         # Thread has vanished
         return True
@@ -67,8 +67,7 @@ def iskthread(pid):
     f.close()
     if line:
         return False
-    # Zombies also doesn't have smaps entries, so check the
-    # state:
+    # Zombies also don't have smaps entries, so check the state:
     try:
         p = procfs.pidstat(pid)
     except:
@@ -89,7 +88,7 @@ def is_irq_thread(cmd):
     return cmd[:4] in ("IRQ-", "irq/")
 
 def threaded_irq_re(irq):
-    return re.compile("(irq/%s-.+|IRQ-%s)" % (irq, irq))
+    return re.compile(f"(irq/{irq}-.+|IRQ-{irq})")
 
 # FIXME: Move to python-linux-procfs
 def has_threaded_irqs(ps):
@@ -97,10 +96,10 @@ def has_threaded_irqs(ps):
     return len(ps.find_by_regex(irq_re)) > 0
 
 def set_irq_affinity_filename(filename, bitmasklist):
-    pathname = "/proc/irq/%s" % filename
+    pathname = f"/proc/irq/{filename}"
     f = open(pathname, "w")
     text = ",".join(["%x" % a for a in bitmasklist])
-    f.write("%s\n" % text)
+    f.write(f"{text}\n")
     try:
         f.close()
     except IOError:
@@ -226,7 +225,7 @@ def move_threads_to_cpu(cpus, pid_list, set_affinity_warning=None, spread=False)
             if pid not in ps:
                 continue
 
-            threads = procfs.pidstats("/proc/%d/task" % pid)
+            threads = procfs.pidstats(f"/proc/{pid}/task")
             for tid in list(threads.keys()):
                 try:
                     curr_affinity = os.sched_getaffinity(tid)
@@ -317,21 +316,15 @@ def affinity_remove_cpus(affinity, cpus, nr_cpus):
         affinity = list(set(affinity) - set(cpus))
     return affinity
 
-# True if machine is s390 or s390x
-def is_s390():
-    machine = platform.machine()
-    if re.search('s390', machine):
-        return True
-    return False
 
-# Shound be moved to python_linux_procfs.interrupts, shared with interrupts.parse_affinity, etc.
+# Should be moved to python_linux_procfs.interrupts, shared with interrupts.parse_affinity, etc.
 def parse_irq_affinity_filename(filename, nr_cpus):
     try:
-        f = open("/proc/irq/%s" % filename)
+        f = open(f"/proc/irq/{filename}")
     except IOError as err:
-        if is_s390():
+        if procfs.is_s390():
             print("This operation is not supported on s390", file=sys.stderr)
-            print("tuna: %s" % err, file=sys.stderr)
+            print(f"tuna: {err}", file=sys.stderr)
             sys.exit(2)
 
     line = f.readline()
@@ -367,6 +360,10 @@ def isolate_cpus(cpus, nr_cpus):
                 if err.args[0] == errno.EINVAL:
                     print("Function:", fname, ",", err.strerror, file=sys.stderr)
                     sys.exit(2)
+                if err.args[0] == errno.EBUSY:
+                    comm = ps[pid].stat["comm"]
+                    print(f'Warning: Unable to isolate pid {pid} [{comm}]')
+                    continue
                 raise err
 
         if "threads" not in ps[pid]:
@@ -431,9 +428,9 @@ def include_cpus(cpus, nr_cpus):
             if err.args[0] == errno.ESRCH:
                 continue
             raise err
-        if set(affinity).intersection(set(cpus)) != set(cpus):
+        if affinity.intersection(set(cpus)) != set(cpus):
             previous_pid_affinities[pid] = copy.copy(affinity)
-            affinity = list(set(affinity + cpus))
+            affinity = list(affinity) + cpus
             try:
                 os.sched_setaffinity(pid, affinity)
             except OSError as err:
@@ -453,9 +450,9 @@ def include_cpus(cpus, nr_cpus):
                 if err.args[0] == errno.ESRCH:
                     continue
                 raise err
-            if set(affinity).intersection(set(cpus)) != set(cpus):
+            if affinity.intersection(set(cpus)) != set(cpus):
                 previous_pid_affinities[tid] = copy.copy(affinity)
-                affinity = list(set(affinity + cpus))
+                affinity = list(affinity) + cpus
                 try:
                     os.sched_setaffinity(tid, affinity)
                 except OSError as err:
@@ -509,16 +506,21 @@ def get_policy_and_rtprio(parm):
     parms = parm.split(":")
     rtprio = 0
     policy = None
-    if parms[0].upper() in ["OTHER", "BATCH", "IDLE", "FIFO", "RR"]:
-        policy = tuna_sched.sched_fromstr("SCHED_%s" % parms[0].upper())
+
+    try:
+        cp = tuna_sched.Policy(parms[0])
+    except:
+        if parms[0].isdigit():
+            rtprio = int(parms[0])
+        else:
+            raise ValueError
+    else:
+        policy = cp.get_policy()
         if len(parms) > 1:
             rtprio = int(parms[1])
-        elif parms[0].upper() in ["FIFO", "RR"]:
+        elif cp.is_rt():
             rtprio = 1
-    elif parms[0].isdigit():
-        rtprio = int(parms[0])
-    else:
-        raise ValueError
+
     return (policy, rtprio)
 
 def thread_filtered(tid, cpus_filtered, show_kthreads, show_uthreads):
@@ -530,7 +532,7 @@ def thread_filtered(tid, cpus_filtered, show_kthreads, show_uthreads):
                 return False
             raise err
 
-        if set(cpus_filtered + affinity) == set(cpus_filtered):
+        if set(cpus_filtered + list(affinity)) == set(cpus_filtered):
             return True
 
     if not (show_kthreads and show_uthreads):
@@ -556,11 +558,8 @@ def thread_set_priority(tid, policy, rtprio):
     os.sched_setscheduler(tid, policy, param)
 
 def threads_set_priority(tids, parm, affect_children=False):
-    try:
-        (policy, rtprio) = get_policy_and_rtprio(parm)
-    except ValueError:
-        print("tuna: " + _("\"%s\" is unsupported priority value!") % parms[0])
-        return
+
+    (policy, rtprio) = parm
 
     for tid in tids:
         try:
@@ -616,7 +615,7 @@ def get_kthread_sched_tunings(proc=None):
 
     return kthreads
 
-def run_command(cmd, policy, rtprio, cpu_list):
+def run_command(cmd, policy, rtprio, cpu_list, background):
     newpid = os.fork()
     if newpid == 0:
         cmd_list = shlex.split(cmd)
@@ -625,22 +624,23 @@ def run_command(cmd, policy, rtprio, cpu_list):
             try:
                 thread_set_priority(pid, policy, rtprio)
             except (SystemError, OSError) as err:
-                print("tuna: %s" % err)
+                print(f"tuna: {err}")
                 sys.exit(2)
         if cpu_list:
             try:
                 os.sched_setaffinity(pid, cpu_list)
             except (SystemError, OSError) as err:
-                print("tuna: %s" % err)
+                print(f"tuna: {err}")
                 sys.exit(2)
 
         try:
             os.execvp(cmd_list[0], cmd_list)
         except (SystemError, OSError) as err:
-            print("tuna: %s" % err)
+            print(f"tuna: {err}")
             sys.exit(2)
     else:
-        os.waitpid(newpid, 0)
+        if not background:
+            os.waitpid(newpid, 0)
 
 def generate_rtgroups(filename, kthreads, nr_cpus):
     f = open(filename, "w")
